# cropwiseworker
# changelog

All noticeable changes to this project will be documented in this file.

The format is based on [Keep a Changelog] (https://keepachangelog.com/en/1.0.0/), and this project adheres to [Semantic Versioning] (https://semver.org/spec/v2.0.0.html).

## [0.0.5] – 2024-07-08

### Added 
- Added a new function for data processing.

## [0.0.2] - 2024-04-12

### Added
- The project was created.
- Added the function of mass loading of data on the Cropwise Operations API.
- Added the function of creating an Agrimatrix report.
- Integration with the external Cropwise Operations API.

